use std::collections::HashMap;
use std::env;
use std::net::SocketAddr;
use crate::config::config::STATIC_ADDR;

pub(crate) fn get_connection_params(
    connection_url: String,
) -> Result<HashMap<String, String>, &'static str> {
    if let Some(query_part) = connection_url.split('?').nth(1) {
        let mut params_mapping = HashMap::new();
        for param in query_part.split('&') {
            if let Some((key, value)) = param.split_once('=') {
                params_mapping.insert(key.to_string(), value.to_string());
            } else {
                return Err("Invalid parameter format, missing '='");
            }
        }
        Ok(params_mapping)
    } else {
        Ok(HashMap::new())
    }
}

// 获取地址的逻辑封装
pub fn get_addr() -> Result<String, Box<dyn std::error::Error>> {
    // 1. 处理命令行参数
    let mut args = env::args().skip(1);
    if let Some(pos) = args.position(|arg| arg == "--addr") {
        // 获取下一个参数值
        return args.nth(pos)
            .ok_or("--addr requires a value".into())
            .and_then(|addr| {
                addr.parse::<SocketAddr>()?;
                Ok(addr)
            });
    }

    // 2. 处理环境变量
    if let Ok(env_addr) = env::var("RS_WS_ADDR") {
        env_addr.parse::<SocketAddr>()?;
        return Ok(env_addr);
    }

    // 3. 返回默认值
    Ok(STATIC_ADDR.to_string())
}